"""
This is the example of generating a synthetic population of the interstellar object
according to Marceta, D.: Orbital Model of the interstellar Objects in the Solar System, 2021.

input:
    v - interstellar velocities of the ISOs (from 1 km/s to 100 km/s with a step of 1 km/s)
    pv - distribution of the interstellar velocities of ISOs given in the array "v" (Maxwell_Boltzmann distribution with sigma=26140 m/s (Eubanks et al. 2021))
    n0 - interstellar number-density of ISOs (1 object cubic au)
    rm - radius of the model sphere (10 au)
    dr - step for the numerical integration with respect to heliocentric distance (1e-3 au)

output:
    q - perihelion distances [au]
    e - eccentricities
    f - true anomalies [degrees]
    inc - orbital inclinations [degrees]
    Omega - longitudes of ascending nodes [degrees]
    omega - arguments of perihelions [degrees]   
"""
import numpy as np
from statistical_method import maxwell_boltzmann, synthetic_population

v=np.arange(1e3, 101e3, 1e3) # interstellar velocities of the ISOs (unperturbed by the Sun's gravity)
pv=maxwell_boltzmann(v, sigma=26140.) # distribution of the interstellar velocities

# generating synthetic population
q,e,f,inc,Omega,omega=synthetic_population(v,pv,n0=1., rm=10, dr=1e-3)

